..
    This file is part of Invenio.
    Copyright (C) 2022 University of Münster.

    Invenio-Serializer-Epicur is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Contributors
============

- Werner Greßhoff
